@@ -12,22 +12,24 @@ from grizzly.tasks.conditional import ConditionalTask  # pylint: disable=no-name
 from .._helpers import add_request_task, get_task_client, is_template
 from ...types import RequestDirection, RequestMethod
 from ...context import GrizzlyContext
-from ...tasks import LogMessageTask, WaitTask, TransformerTask, UntilRequestTask, DateTask, AsyncRequestGroupTask, TimerTask, TaskWaitTask
+from ...tasks import (
+    LogMessageTask,
+    WaitTask,
+    TransformerTask,
+    UntilRequestTask,
+    DateTask,
+    AsyncRequestGroupTask,
+    TimerTask,
+    TaskWaitTask,
+    LoopTask,
+)
 
 from grizzly_extras.transformer import TransformerContentType
 
 
-def parse_method(text: str) -> RequestMethod:
-    return RequestMethod.from_string(text.strip())
-
-
-def parse_direction(text: str) -> RequestDirection:
-    return RequestDirection.from_string(text.strip())
-
-
 register_type(
-    Direction=parse_direction,
-    Method=parse_method,
+    Direction=RequestDirection.from_string,
+    Method=RequestMethod.from_string,
     ContentType=TransformerContentType.from_string,
 )
 
@@ -540,7 +542,7 @@ def step_task_async_group_close(context: Context) -> None:
     async_group = grizzly.scenario.tasks.tmp.async_group
 
     assert async_group is not None, 'no async request group is open'
-    assert len(async_group.requests) > 0, f'there are no requests in async group "{async_group.name}"'
+    assert len(async_group.tasks) > 0, f'there are no requests in async group "{async_group.name}"'
 
     grizzly.scenario.tasks.tmp.async_group = None
     grizzly.scenario.tasks.add(async_group)
@@ -740,3 +742,56 @@ def step_task_conditional_end(context: Context) -> None:
     conditional = grizzly.scenario.tasks.tmp.conditional
     grizzly.scenario.tasks.tmp.conditional = None
     grizzly.scenario.tasks.add(conditional)
+
+
+@then(u'loop "{values}" as variable "{variable}" with name "{name}"')
+def step_task_loop_start(context: Context, values: str, variable: str, name: str) -> None:
+    """
+    Creates an instance of the {@pylink grizzly.tasks.loop} tasks which executes all wrapped tasks with a value from the list `values`.
+    `values` **must** be a valid JSON list and supports {@link framework.usage.variables.templating}.
+
+    See {@pylink grizzly.tasks.loop} task documentation for more information.
+
+    Example:
+
+    ``` gherkin
+    Then loop "{{ loop_values }}" as variable "loop_value" with name "test-loop"
+    Then log message "loop_value={{ loop_value }}"
+    Then end loop
+    ```
+    """
+    grizzly = cast(GrizzlyContext, context.grizzly)
+
+    assert grizzly.scenario.tasks.tmp.loop is None, f'loop task "{grizzly.scenario.tasks.tmp.loop.name}" is already open, close it first'
+
+    grizzly.scenario.tasks.tmp.loop = LoopTask(
+        grizzly=grizzly,
+        name=name,
+        values=values,
+        variable=variable
+    )
+
+
+@then(u'end loop')
+def step_task_loop_end(context: Context) -> None:
+    """
+    Closes the {@pylink grizzly.tasks.loop} task created by {@pylink grizzly.steps.scenario.tasks.step_task_loop_start}.
+    This means that any following tasks specified will not be part of the loop.
+
+    See {@pylink grizzly.tasks.loop} task documentation for more information.
+
+    Example:
+
+    ``` gherkin
+    Then loop "{{ loop_values }}" as variable "loop_value" with name "test-loop"
+    Then log message "loop_value={{ loop_value }}"
+    Then end loop
+    ```
+    """
+    grizzly = cast(GrizzlyContext, context.grizzly)
+
+    assert grizzly.scenario.tasks.tmp.loop is not None, 'there are no open loop, you need to create one before closing it'
+
+    loop = grizzly.scenario.tasks.tmp.loop
+    grizzly.scenario.tasks.tmp.loop = None
+    grizzly.scenario.tasks.add(loop)
