@@ -1,29 +1,44 @@
-'''This task performs Azure Blob Storage get or put operations to a specified endpoint.
+'''This task performs Azure Blob Storage put operations to a specified endpoint.
 
 This is useful if the scenario is another user type than `BlobStorageUser`, but the scenario still requires an action towards a blob container.
 
-Endpoint is specified in the format:
+Only supports `RequestDirection.TO`.
 
-```plain
+## Step implementations
+
+* {@pylink grizzly.steps.scenario.tasks.step_task_client_put_endpoint_file_destination}
+
+## Arguments
+
+* `direction` _RequestDirection_ - if the request is upstream or downstream
+
+* `endpoint` _str_ - specifies details to be able to perform the request, e.g. account and container information
+
+* `name` _str_ - name used in `locust` statistics
+
+* `destination` _str_ (optional) - name of the file when uploaded, if not specified the basename of `source` will be used
+
+* `source` _str_ (optional) - file path of local file that should be saved in `Container`
+
+## Format
+
+### `endpoint`
+
+``` plain
 bs[s]://<AccountName>?AccountKey=<AccountKey>&Container=<Container>
 ```
 
-All variables in the endpoint supports templating, but not the whole string.
+* `AccountName` _str_ - name of storage account
 
-Content-Type of an uploaded file will automagically be guessed based on the [rendered] destination file extension.
+* `AccountKey` _str_ - secret key to be able to "connect" to the storage account
 
-Example:
+* `Container` _str_ - name of the container to perform the request on
 
-```plain
-bss://my-storage?AccountKey=aaaabbbb==&Container=my-container
-```
+All variables in the endpoint supports {@link framework.usage.variables.templating}, but not the whole string.
 
-This will be resolved to `DefaultEndpointsProtocol=https;AccountName=my-storage;AccountKey=aaaabbbb==;EndpointSuffix=core.windows.net`, and operations
-will be performed in container `my-container`.
+### `destination`
 
-Instances of this task is created with the step expression, if endpoint is defined with scheme `bs`:
-
-* [`step_task_client_put_endpoint_file_destination`](/grizzly/framework/usage/steps/scenario/tasks/#step_task_client_put_endpoint_file_destination)
+The MIME type of an uploaded file will automagically be guessed based on the [rendered] destination file extension.
 '''
 import logging
 
@@ -58,21 +73,20 @@ class BlobStorageClientTask(ClientTask):
     def __init__(
         self,
         direction: RequestDirection,
-        endpoint: str, /,
+        endpoint: str,
+        name: Optional[str] = None,
+        /,
         variable: Optional[str] = None,
         source: Optional[str] = None,
         destination: Optional[str] = None,
         scenario: Optional[GrizzlyContextScenario] = None,
     ) -> None:
-        super().__init__(direction, endpoint, variable=variable, destination=destination, source=source, scenario=scenario)
+        super().__init__(direction, endpoint, name, variable=variable, destination=destination, source=source, scenario=scenario)
 
         parsed = urlparse(self.endpoint)
 
         self._endpoints_protocol = 'http' if parsed.scheme == 'bs' else 'https'
 
-        if self.source is None and self.direction == RequestDirection.TO:
-            raise ValueError(f'{self.__class__.__name__}: source must be set for direction {self.direction.name}')
-
         if parsed.netloc is None or len(parsed.netloc) < 1:
             raise ValueError(f'{self.__class__.__name__}: could not find account name in {self.endpoint}')
 
@@ -105,12 +119,6 @@ class BlobStorageClientTask(ClientTask):
         else:
             destination = Path(source).name
 
-        source_file = Path(self._context_root) / 'requests' / source
-
-        if source_file.exists():
-            source = source_file.read_text()
-            source = parent.render(source)
-
         content_type, _ = mimetype_guess(destination)
 
         if content_type is None:
@@ -118,8 +126,14 @@ class BlobStorageClientTask(ClientTask):
 
         content_settings = ContentSettings(content_type=content_type)
 
-        with self.action(parent) as meta:
+        with self.action(parent, action=self.container) as meta:
+            source_file = Path(self._context_root) / 'requests' / source
+
+            if not source_file.exists():
+                raise FileNotFoundError(source)
+
+            source = parent.render(source_file.read_text())
+
             with self.service_client.get_blob_client(container=self.container, blob=destination) as blob_client:
                 blob_client.upload_blob(source, content_settings=content_settings)
                 meta['response_length'] = len(source)
-                meta['action'] = f'{self.container}'
